############################
#
# initrd, building the initrd.gz file.
#
# this is a bit special than most other .mk files since it will always 
# build the file, regardeless the exsistence of a initrd.gz file.
#
# The reasons are that we don't know which type of initrd.gz file we have, 
# we do make two of'em here already (IDE and basic) and since the building
# of the images, initrd.gz and add.bz2 are separate from the rest, you never
# really know when to build or not. 
#
# So, this is being on the safe side.
#
##########################

TMP_MNT=/tmp/mnt
TMP_INITRD=/tmp/initrd
MKFS_MINIX=mkfs.minix

initrd-base: $(INITRD_MASTER)
	-[ -d $(TMP_MNT) ] && rm -rf $(TMP_MNT)
	-[ -f $(TMP_INITRD) ] && rm -f $(TMP_INITRD)

	dd if=/dev/zero of=$(TMP_INITRD) count=768 bs=1024
	
	$(MKFS_MINIX) $(TMP_INITRD)
	mkdir $(TMP_MNT)
	mount -t minix -o loop $(TMP_INITRD) $(TMP_MNT)
	cp -a $(INITRD_MASTER)/* $(TMP_MNT)/.
	cp -a $(SCRIPTS_DIR)/linuxrc $(TMP_MNT)/.
	cp -a $(SCRIPTS_DIR)/rc.initrd $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/functions.inc $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/inittab $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/inittab.serial $(TMP_MNT)/etc/.
	
	(cd $(TMP_MNT)/dev ; \
		mknod -m 600 console c 5 1; \
		mknod -m 600 tty0 c 4 0; \
		mknod -m 600 tty1 c 4 1; \
		mknod -m 660 ram0 b 1 0; \
	);
	sync
	umount $(TMP_MNT)
	gzip -9 $(TMP_INITRD)
	# bzip2 -9 $(TMP_INITRD)
	mv $(TMP_INITRD).gz $(INITRD_DIR)/initrd.gz


# I wish I didn't have to repeat the whole thing here:
# This has a dependancy of idemods (which could trigger quite alot) but
# idemods.bz2 are the whole point of this.
initrd-ide: $(INITRD_MASTER) $(MODULES_BASE_DIR)/idemods.bz2
	-[ -d $(TMP_MNT) ] && rm -rf $(TMP_MNT)
	-[ -f $(TMP_INITRD) ] && rm -f $(TMP_INITRD)

	dd if=/dev/zero of=$(TMP_INITRD) count=1536 bs=1024
	
	$(MKFS_MINIX) $(TMP_INITRD)
	mkdir $(TMP_MNT)
	mount -t minix -o loop $(TMP_INITRD) $(TMP_MNT)
	cp -a $(INITRD_MASTER)/* $(TMP_MNT)/.
	cp -a $(SCRIPTS_DIR)/linuxrc $(TMP_MNT)/.
	cp -a $(SCRIPTS_DIR)/rc.initrd $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/functions.inc $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/inittab $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/inittab.serial $(TMP_MNT)/etc/.

	bzcat $(MODULES_BASE_DIR)/idemods.bz2 | tar -C $(TMP_MNT) -xvf -

	(cd $(TMP_MNT)/dev ; \
		mknod -m 600 console c 5 1; \
		mknod -m 600 tty0 c 4 0; \
		mknod -m 600 tty1 c 4 1; \
		mknod -m 660 ram0 b 1 0; \
	);
	sync
	umount $(TMP_MNT)
	gzip -9 $(TMP_INITRD)
	# bzip2 -9 $(TMP_INITRD)
	mv $(TMP_INITRD).gz $(INITRD_DIR)/initrd.gz

initrd-flash: $(INITRD_MASTER) $(MODULES_BASE_DIR)/idemods.bz2 $(MODULES_BASE_DIR)/usbmods.bz2
	-[ -d $(TMP_MNT) ] && rm -rf $(TMP_MNT)
	-[ -f $(TMP_INITRD) ] && rm -f $(TMP_INITRD)

	dd if=/dev/zero of=$(TMP_INITRD) count=2048 bs=1024
	
	$(MKFS_MINIX) $(TMP_INITRD)
	mkdir $(TMP_MNT)
	mount -t minix -o loop $(TMP_INITRD) $(TMP_MNT)
	cp -a $(INITRD_MASTER)/* $(TMP_MNT)/.
	cp -a $(SCRIPTS_DIR)/linuxrc $(TMP_MNT)/.
	cp -a $(SCRIPTS_DIR)/rc.initrd $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/functions.inc $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/inittab $(TMP_MNT)/etc/.
	cp -a $(SCRIPTS_DIR)/inittab.serial $(TMP_MNT)/etc/.

	bzcat $(MODULES_BASE_DIR)/idemods.bz2 | tar -C $(TMP_MNT) -xvf -
	bzcat $(MODULES_BASE_DIR)/usbmods.bz2 | tar -C $(TMP_MNT) -xvf -

	(cd $(TMP_MNT)/dev ; \
		mknod -m 600 console c 5 1; \
		mknod -m 600 tty0 c 4 0; \
		mknod -m 600 tty1 c 4 1; \
		mknod -m 660 ram0 b 1 0; \
	);
	sync
	umount $(TMP_MNT)
	gzip -9 $(TMP_INITRD)
	# bzip2 -9 $(TMP_INITRD)
	mv $(TMP_INITRD).gz $(INITRD_DIR)/initrd.gz

initrd-clean: 
	-rm -f $(INITRD_DIR)/initrd.gz
	-rm -f $(BASE_DIR)/floppy/initrd.gz

initrd-dirclean: 
	-rm -f $(INITRD_DIR)/initrd.gz
	-rm -rf $(INITRD_MASTER)
	
